# ****************************************************
#   PROCEDURY VOLAN HLAVNM PROGRAMEM 
# ****************************************************
# ****************************************************
Fuel:=proc(DensityUnit,DensityValue,roair15,Tfuelsupply)
# Vpoet hustoty paliva, kg/m3
# Vstupn parametry:
#    DensityUnit - typ hustoty paliva
#    DensityValue - hustota paliva
#    Tfuelsupply - teplota paliva, deg C
#    roair15 - hustota vzduchu pi NP, kg/m3
local rofuel;
if DensityUnit=2 then  
rofuel:=DensityValue*roair15; 
else
rofuel:=DensityValue*(Tfuelsupply+273.15)/298.15;  
end if;
return rofuel;
end proc:
# ****************************************************
# ****************************************************
FgrX := proc(FuelType,X)
# Vpoet pomru spalin na jednotku uvolnnho tepla, kJ/kg
# Vstupn parametry:
#    FuelType - typ paliva, - (1 = topn plyn, 2 = topn olej)
#    X - pebytek spalovacho vzduchu
local abc;
if FuelType = 1
then
abc := 1280;
else
abc := 1380;
end if;
return abc+12*X;
end proc:
# ****************************************************
# ****************************************************
MerEnt := proc(THV,Temp)
# Korelan vpoet mrn entalpie spalin, kJ/kg
# Vstupn parametry:
#    THV - typ vhevnosti, - (1 = LHV, 2 = HHV)
#    Temp - teplota spalin, C
local Aalfa, Bbeta;
if THV = 1
then
Aalfa := -30.7302785;
Bbeta := 1.19090080;
else
Aalfa := 205.192307;
Bbeta := 1.19465034;
end if;
return Aalfa+Bbeta*Temp;
end proc:
# ****************************************************
# ****************************************************
Tfg := proc(THV,Hfg)
# Korelan vpoet teploty spalin, C
# Vstupn parametry:
#    THV - typ vhevnosti, - (1 = LHV, 2 = HHV)
#    Hfg - mrn entalpie spalin, kJ/kg
local Aalfa, Bbeta;
if THV = 1
then
Aalfa := -30.7302785;
Bbeta := 1.19090080;
else
Aalfa := 205.192307;
Bbeta := 1.19465034;
end if;
return (Hfg-Aalfa)/Bbeta;
end proc:
# ****************************************************
# ****************************************************
hcon := proc(ODmm,T,mfg_kgs)
# Korelan vpoet souinitele pestupu tepla spalin, W/(m^2.C)
# Vstupn parametry:
#    ODmm - vnj prmr konveknch trubek, mm
#    T - vztan teplota spalin pro konvekci, C
#    mfg_kgs - hmotnostn prtok spalin, kg/s
local CA1, CB1, CC1, CD1, CA2, CB2, CC2, CD2, CA3, CB3, CC3, CD3, CA4, CB4, CC4, CD4, ca, cb, cc, cd;
CA1 := 4.955004725;
CB1 := -847.5657696;
CC1 := 242256.423;
CD1 := -27311986.387;
CA2 := -2.626696297;
CB2 := 406.5789429;
CC2 := 27470.44931;
CD2 := -17040804.17;
CA3 := 1.367664112;
CB3 := -247.2637134;
CC3 := -60318.42028;
CD3 := 19544314.875;
CA4 := -.2426865939;
CB4 := 16.62288813;
CC4 := 31812.88441;
CD4 := -7157018.90;
if ODmm<101.0
then
CA1 := 4.918737132;
CB1 := -908.329571;
CC1 := 375751.009;
CD1 := -58143710.94;
CA2 := -1.72287207;
CB2 := -38.7317314;
CC2 := -125749.0884;
CD2 := 38647053.44;
CA3 := 0.57447120608;
CB3 := 184.636037;
CC3 := 37035.69982;
CD3 := -21465920.72;
CA4 := -0.3742830645e-1;
CB4 := -95.04240999;
CC4 := 8954.1624502;
CD4 := 2800546.3579;
end if;
if ODmm > 140.0
then
CA1 := 4.597974856;
CB1 := -662.358437;
CC1 := 195364.904;
CD1 := -19984030.3;
CA2 := -1.856362745;
CB2 := -445.4201835;
CC2 := 264223.037;
CD2 := -52492167.89;
CA3 := .95280937416;
CB3 := 146.5756727;
CC3 := -74065.50924;
CD3 := 18263744.5;
CA4 := -.2243710488;
CB4 := 36.490362918;
CC4 := -24517.973416;
CD4 := 2775696.28819;
end if;
ca := CA1+CB1/T+CC1/(T*T)+CD1/((T*T)*T);
cb := CA2+CB2/T+CC2/(T*T)+CD2/((T*T)*T);
cc := CA3+CB3/T+CC3/(T*T)+CD3/((T*T)*T);
cd := CA4+CB4/T+CC4/(T*T)+CD4/((T*T)*T);
return exp(ca+cb/mfg_kgs+cc/mfg_kgs^2+cd/mfg_kgs^3);
end proc:
# ****************************************************
# ****************************************************
Frk := proc(Qrt,Gcor)
# Korelan vpoet podlu tepla absorbovanho v radian sekci, -
# Vstupn parametry:
#    Qrt - tepeln zaten trubek v radian sekci, W/m2
#    Gcor - pln zkorigovan mrn spoteba vzduchu, kg_air/kg_fuel
local A1, B1, C1, D1, A2, B2, C2, D2, A3, B3, C3, D3, A4, B4, C4, D4, a, b, c, d;
A1 := 1.7718493787;
B1 := -0.10019117635e-3;
C1 := 0.37534689295e-8;
D1 := -0.4191035072e-13;
A2 := -.1366921187;
B2 := 0.1531156947e-4;
C2 := -0.5963858747e-9;
D2 := 0.6684546867e-14;
A3 := 0.6519753696e-2;
B3 := -0.81321392297e-6;
C3 := 0.3085147199e-10;
D3 := -0.3435592722e-15;
A4 := -0.1108513055e-3;
B4 := 0.1383758239e-7;
C4 := -0.5172400596e-12;
D4 := 0.5748038181e-17;
a := A1+B1*Qrt+C1*Qrt*Qrt+(D1*Qrt*Qrt)*Qrt;
b := A2+B2*Qrt+C2*Qrt*Qrt+(D2*Qrt*Qrt)*Qrt;
c := A3+B3*Qrt+C3*Qrt*Qrt+(D3*Qrt*Qrt)*Qrt;
d := A4+B4*Qrt+C4*Qrt*Qrt+(D4*Qrt*Qrt)*Qrt;
return a+b*Gcor+c*Gcor*Gcor+(d*Gcor*Gcor)*Gcor;
end proc:
# ****************************************************
# ****************************************************
Egro := proc(X,Tge)
# Vpoet innosti, -
# Vstupn parametry:
#    X - pebytek vzduchu
#    Tge - teplota spalin na vstupu z pece
local Aa,Ba,Ca,Da,Ab,Bb,Cb,Db,Ac,Bc,Cc,Dc,Ad,Bd,Cd,Dd,dda,ddb,ddc,ddd;
if Tge < 400 then
 Aa := 3.5867271007;
 Ba := 0.597137044e-3;
 Ca := -0.1041459411e-3;
 Da := 0.2706436001e-6;
 Ab := 807.07270036;
 Bb := -3.800851813;
 Cb := 0.13006679819;
 Db := -0.3538013227e-3;
 Ac := -253163.10679;
 Bc := 2106.2599069;
 Cc := -51.739316869;
 Dc := 0.146145027479;
 Ad := 27339387.6175;
 Bd := -307805.9945;
 Cd := 6622.921581;
 Dd := -19.27246931;
else 
 Aa := 1.80332283009;
 Ba := -0.1199075376;
 Ca := 0.2116704420e-2;
 Da := -0.1940342135e-4;
 Ab := 4669.3314389;
 Bb := 244.0655075;
 Cb := -4.6657851398;
 Db := 0.4444289104e-1;
 Ac := -3063354.486;
 Bc := -169095.9337;
 Cc := 3400.89217929;
 Dc := -33.787223665;
 Ad := 712888042.7;
 Bd := 39359869.33;
 Cd := -821335.24884;
 Dd := 8523.7594268;
end if;
dda:=(Aa+Ba*X+Ca*X*X+Da*X*X*X);
ddb := Ab+Bb*X+Cb*X*X+(Db*X*X)*X;
ddc := Ac+Bc*X+Cc*X*X+(Dc*X*X)*X;
ddd:=Ad+Bd*X+Cd*X*X+Dd*X*X*X;
return dda+ddb/Tge+ddc/(Tge^2)+ddd/(Tge^3);
end proc:
# ****************************************************
# ****************************************************
AIRro := proc(Tair,Humidity)
# Vpoet hustoty pvdnho spalovacho vzduchu, kg/m3
# Vstupn parametry:
#    Tair - teplota pivdnho spalovacho vzduchu, C
#    Humidity - vlhkost spalin, %
local Hum,TairK,pv,pp;
Hum:=Humidity/100;
TairK:=Tair+273.15;
pv:=exp(28.926-(6148/TairK));#platn pro teploty 0-80C
pp:=101325;#poedpoklad ?e se vzduch poivd pod atm. tlakem
return (0.001316/TairK)*(2.65*pp+Hum*pv);
end proc:
# ****************************************************
# ****************************************************
LHVp := proc(LHVm, xCH4, xC3H8, xC4H10, xC5H12, xC6H14, xH2, MWCH4, MWC3H8, MWC4H10, MWC5H12, MWC6H14, MWH2)
# Vpoet hustoty pvdnho spalovacho vzduchu, kg/m3
# Vstupni parametry:
#    LHVm - vhevnost paliva, kJ/kg
#    xCxHx - podl jednotlivch sloek v palivu, -
#    MWCxHx - molrn hmotnosti jednotlivch sloek paliva, kg/kmol
local MWstr;
MWstr:=xCH4*MWCH4+xC3H8*MWC3H8+xC4H10*MWC4H10+xC5H12*MWC5H12+xC6H14*MWC6H14+xH2*MWH2;
return LHVm*MWstr/22.414;
end proc:
# ****************************************************
# ****************************************************
AIRv := proc(X, xCH4, xC3H8, xC4H10, xC5H12, xC6H14, xH2)
# Vpoet objemu pivdnho spalovacho vzduchu, kg/m3
# Vstupn parametry:
#    X - pebytek vzduchu, %
#    xCxHx - podl jednotlivch sloek v palivu, -
return (2*xCH4+5*xC3H8+6.5*xC4H10+8*xC5H12+9.5*xC6H14+0.5*xH2)*(1+X/100)/0.2095;
end proc:
# ****************************************************
# ****************************************************
LHVp2 := proc(LHVm, xCH4,xC2H6, xC3H8, xC4H10, xC5H12, xC6H14, xCO2,xO2,xN2, MWCH4,MWC2H6, MWC3H8, MWC4H10, MWC5H12, MWC6H14, MWCO2, MWO2,MWN2)
# Vpoet hustoty pivdnho spalovacho vzduchu, kg/m3
# Vstupn parametry:
#    LHVm - vhevnost paliva, kJ/kg
#    xCxHx - podl jednotlivch sloek v palivu, -
#    MWCxHx - molrn hmotnosti jednotlivch sloek paliva, kg/kmol
local MWstr;
MWstr:=xCH4*MWCH4+xC2H6*MWC2H6+xC3H8*MWC3H8+xC4H10*MWC4H10+xC5H12*MWC5H12+xC6H14*MWC6H14+xCO2*MWCO2+xO2*MWO2+xN2*MWN2;
return LHVm*MWstr/22.414;
end proc:
# ****************************************************
# ****************************************************
AIRv2 := proc(X, xCH4,xC2H6, xC3H8, xC4H10, xC5H12, xC6H14, xO2,xN2)
# Vpoet objemu pivdnho spalovacho vzduchu, kg/m3
# Vstupn parametry:
#    X - pebytek vzduchu, %
#    xCxHx - podl jednotlivch sloek v palivu, -
return (2*xCH4+3.5*xC2H6+5*xC3H8+6.5*xC4H10+8*xC5H12+9.5*xC6H14+2*xN2-1*xO2)*(1+X/100)/0.2095;
end proc:
# ****************************************************
# ****************************************************
etafin := proc(hf,lamfin,tfin,Doutf,Doutc)
# Vpoet skuten innosti ebrovn - Schmidtova metoda
# Vstupni parametry:
#    hf - vka eber
#    lamfin - souinitel pestupu tepla ebrovn
#    tfin - tlouka eber
#    Doutf - vnj prmr ebrovan trubky
#    Doutc - vnj prmr hladk trubky
local parM,parRx,parRo,parLx,etaf;
parM:=((2*hf)/(lamfin*tfin))^0.5;#parametr M
parRx:=(Doutf-Doutc)/2;#parametr R*
parRo:=(Doutf/Doutc);#parametr Ro
parLx:=parRx*(1+tfin/(2*parRx))*(1+0.35*ln(parRo));#parametr L*
etaf:=tanh(parM*parLx)/(parM*parLx);
return etaf;
end proc:
# ****************************************************
# ****************************************************
pvysledkypr0 := proc()
#Vpis vsledk pro ovovac vpoet
  printf("*********************************************************\n");
  printf("\n");
  printf("VPIS VSLEDKU:\n");
  printf("---------------\n");
  printf("F - podl absorbovanho tepla v RK, -:       %7.2f\n", F);
  printf("G - pomr vzduchu na jednotku paliva, -:     %7.2f\n", G);
  printf("Teplo absorbovan v RK, MW:                  %7.2f\n", Qr/1000000);
  printf("Plocha radiace, m2:                          %7.2f\n", Ar);
  printf("Teplo vyvinut, MW:                          %7.2f\n", Qv/1000000);
  printf("Tepeln tok z RK,MW:                         %7.2f\n", Qre/1000000);
  printf("Teplota spalin na jzku, deg C:              %7.2f\n", Tgasre);
  printf("innost pece, -:                            %7.2f\n", Eg);
  printf("1. ada stncch trubek:\n");
  printf("---------------\n");
  printf("Pruton hmot. rychlost spalin, kg/s.m2:     %7.2f\n", Ggasr);
  printf("Sou. pestupu tepla, W/m2.degC:             %7.2f\n", h0);
  printf("Pedan teplo, MW:                           %7.2f\n", Qcr/1000000);
  printf("Tepeln tok na vstupu, MW:                  %7.2f\n", Qexitgases1/1000000);
  printf("Teplota na vstupu, deg C:                   %7.2f\n", Tg1exit);
  printf("2. ada stncch trubek:\n");
  printf("---------------\n");
  printf("Pruton hmot. rychlost spalin,kg/s.m2:      %7.2f\n", Ggasr);
  printf("Sou. pestupu tepla, W/m2.degC:             %7.2f\n", h02);
  printf("Pedan teplo, MW:                           %7.2f\n", Qcr2/1000000);
  printf("Tepeln tok na vstupu, MW:                  %7.2f\n", Qexitgases2/1000000);
  printf("Teplota na vstupu, deg C:                   %7.2f\n", Tgexit2);
  printf("ebrovan st KS:\n");
  printf("---------------\n");
  printf("Prton hmot. rychlost spalin,kg/s.m2:      %7.2f\n", Ggasc);
  printf("Pedan teplo, MW:                           %7.2f\n", Qfin/1000000);
  printf("Tepeln tok na vstupu z pece, MW:           %7.2f\n", Qexit/1000000);
  printf("Komnov teplota spalin, deg C:              %7.2f\n", Tge);
  printf("innost ebrovn, -:                       %7.2f\n", eta[f]);
  printf("Plocha vmny tepla ebrovn, m2:           %7.2f\n", Ao);
  printf("Celkov dlka ebrovanch trubek, m:         %7.2f\n", Lpipe);
  printf("\n");
  printf("*********************************************************\n");
end proc:
# ****************************************************
# ****************************************************
pvysledkypr1 := proc()
#Vpis vsledk pro ppad 1
  printf("*********************************************************\n");
  printf("\n");
  printf("VPIS VSLEDK:\n");
  printf("---------------\n");
  printf("Tepeln innost RK pece, - :      %6.2f\n", etaPec);
  printf("Tep.zaten povrchu trubek, W/m2:  %7.2f\n", Qrt);
 printf("Plocha radiace, m2:                 %7.2f\n", Ar);
  printf("Teplo vyvinut, MW:                 %7.2f\n", Qv);
 printf("Mnostv paliva, kg/h :             %7.2f\n", mfuelh);
  printf("Mnostv spalin, kg/s:              %7.2f\n", mgas_kg_s);
  printf("Teplota spalin na jzku, deg C:     %7.2f\n", Trkexit);
  printf("\n");
  printf("*********************************************************\n");
end proc:
# ****************************************************
# ****************************************************
pvysledkypr2 := proc()
#Vpis vsledk pro ppad 2
  printf("*********************************************************\n");
  printf("\n");
  printf("VPIS VSLEDK:\n");
  printf("---------------\n");
  printf("Tepeln innost RK pece, -:          %7.2f\n", NTE);
  printf("Tep.zaten povrchu trubek, W/m2:     %7.2f\n", Qrt);
  printf("Plocha radiace, m2:                   %7.2f\n", Ar);
  printf("Teplo pedan radian sekc, MW:      %7.2f\n", Qr);
  printf("Teplo vyvinut, MW:                    %7.2f\n", Qv);
  printf("Mnostv paliva, kg/h:                %7.2f\n", mfuel);
  printf("Mnostv spalin, kg/s:                 %7.2f\n", mgases);
  printf("Teplota spalin na jzku, deg C:        %7.2f\n", Trexit);
  printf("KS1:\n");
  printf("Teplota mdia vstup, deg C:            %7.2f\n", TmediaINv);
  printf("Teplota mdia vystup, deg C:           %7.2f\n", TmediaOUTv);
  printf("Abs.teplo, MW:                         %7.2f\n", Q1c);
  printf("Teplota spalin vstup, deg C:           %7.2f\n", T11);
  printf("Teplota spalin vstup, deg C:          %7.2f\n", Texit1);
  printf("Rychlost spalin, kg/m2.s:              %7.2f\n", Gg11);
  printf("Plocha-hladk trub., m2:               %7.2f\n", S1c);
  printf("Sou.pestupu tepla spalin, W/m2.K:    %7.2f\n", h11);
  printf("Mnostv spalin za sekc, kg/s:        %7.2f\n", mgases);
 printf("KS2:\n");
  printf("Teplota mdia vstup, deg C:            %7.2f\n", TmediaINvv);
  printf("Teplota mdia vstup, deg C:           %7.2f\n", TmediaOUTvv);
  printf("Abs.teplo, MW:                         %7.2f\n", Q2);
  printf("Teplota spalin vstup, deg C:           %7.2f\n", T2);
  printf("Teplota spalin vstup, deg C:          %7.2f\n", Texit2);
  printf("Rychlost spalin, kg/m2.s:              %7.2f\n", Gg2);
  printf("Plocha-hladk trub., m2:               %7.2f\n", S2);
  printf("Sou.pestupu tepla spalin, W/m2.K:    %7.2f\n", h2);
  printf("Mnostv spalin za sekc, kg/s:        %7.2f\n", mgases);
 printf("KS3:\n");
  printf("Teplota mdia vstup, deg C:            %7.2f\n", TmediaINvvv);
  printf("Teplota mdia vstup, deg C:           %7.2f\n", TmediaOUTvvv);
  printf("Abs.teplo, MW:                         %7.2f\n", Q3);
  printf("Teplota spalin vstup, deg C:           %7.2f\n", T3);
  printf("Teplota spalin vstup, deg C:          %7.2f\n", Texit3);
  printf("Rychlost spalin, kg/m2.s:              %7.2f\n", Gg3);
  printf("Plocha-hladk trub., m2:               %7.2f\n", S3);
  printf("Sou.pestupu tepla spalin, W/m2.K:    %7.2f\n", h3);
  printf("Mnostv spalin za sekc, kg/s:        %7.2f\n", mgases);
  printf("Teplo absorbovan celkem, MW:          %7.2f\n", Qabsv);
  printf("\n");
  printf("*********************************************************\n");
end proc:
# ****************************************************
# ****************************************************
pvysledkypr3 := proc()
#Vpis vsledk pro ppad 3
  printf("*********************************************************\n");
  printf("\n");
  printf("VPIS VSLEDK:\n");
  printf("---------------\n");
  printf("Tepeln innost RK pece:                %7.2f\n", NTE);
  printf("Tep.zaten povrchu trubek, W/m2:      %7.2f\n", Qrt);
  printf("Plocha radiace,m2:                      %7.2f\n", Ar);
  printf("Teplo pedan radian sekc, MW:       %7.2f\n", Qr);
  printf("Teplo vyvinut, MW:                     %7.2f\n", Qv);
  printf("Mnostv paliva,kg/h :                  %7.2f\n", mfuel);
  printf("Mnostv spalin, kg/s:                  %7.2f\n", mgases);
  printf("Teplota spalin na jzku, deg C:         %7.2f\n", Trexit);
  printf("KS1:\n");
  printf("Teplota mdia vstup, deg C:             %7.2f\n", TmediaINv);
  printf("Teplota mdia vstup, deg C:            %7.2f\n", TmediaOUTv);
  printf("Abs.teplo, MW:                          %7.2f\n", Q1c);
  printf("Teplota spalin vstup, deg C:            %7.2f\n", T1);
  printf("Teplota spalin vstup, deg C:           %7.2f\n", Texit12);
  printf("Rychlost spalin, kg/m2.s:               %7.2f\n", Gg1);
  printf("Plocha-hladk trub., m2:                %7.2f\n", S1);
  printf("Sou.pestupu tepla spalin, W/m2.K:     %7.2f\n", h1);
  printf("Mnostv spalin za sekc, kg/s:         %7.2f\n", mgases);
  printf("KS2:\n");
  printf("Teplota mdia vstup, deg C:             %7.2f\n", TmediaINvv);
  printf("Teplota mdia vstup, deg C:            %7.2f\n", TmediaOUTvv);
  printf("Abs.teplo, MW:                          %7.2f\n", Qfin);
  printf("Teplota spalin vstup, deg C:            %7.2f\n", T2);
  printf("Teplota spalin vstup, deg C:           %7.2f\n", Texit2);
  printf("Rychlost spalin, kg/m2.s:               %7.2f\n", Gg2);
  printf("Plocha-celkov trub., m2:               %7.2f\n", Sfinreal);
  printf("Sou.pestupu tepla spalin, W/m2.K:     %7.2f\n", h2);
  printf("Mnostv spalin za sekc, kg/s:         %7.2f\n", mgases);
  printf("Absorbovan teplo v cel KS, MW:        %7.2f\n", Qabsconv);
  printf("\n");
  printf("*********************************************************\n");
end proc:
# ****************************************************
# ****************************************************
